@@ -65,10 +65,13 @@ def setup_logger(log_level: Text):
     logging.basicConfig(level=log_level, handlers=[RichHandler(level=logging.INFO)])
     if log_level == "INFO":
         logger.level = logging.INFO
+        logging.getLogger('asyncio').setLevel(logging.INFO)
     elif log_level == "DEBUG":
         logger.level = logging.DEBUG
+        logging.getLogger('asyncio').setLevel(logging.DEBUG)
     elif log_level == "ERROR":
         logger.level = logging.ERROR
+        logging.getLogger('asyncio').setLevel(logging.ERROR)
 
 
 def get_logo():
